@@ -17,7 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/** 
+/**
  * \file payloadtype.h
  * \brief Definition of payload types
  *
@@ -34,15 +34,18 @@ extern "C"{
 /* flags for PayloadType::flags */
 
 #define	PAYLOAD_TYPE_ALLOCATED (1)
-	/* private flags for future use by ortp */
-#define	PAYLOAD_TYPE_PRIV1 (1<<1)
-#define	PAYLOAD_TYPE_PRIV2 (1<<2)
-#define	PAYLOAD_TYPE_PRIV3 (1<<3)
-	/* user flags, can be used by the application on top of oRTP */
+/*payload type represents a VBR codec*/
+#define	PAYLOAD_TYPE_IS_VBR (1<<1)
+#define	PAYLOAD_TYPE_RTCP_FEEDBACK_ENABLED (1<<2)
+/* private flags for future use by ortp */
+#define	PAYLOAD_TYPE_PRIV1 (1<<3)
+/* user flags, can be used by the application on top of oRTP */
 #define	PAYLOAD_TYPE_USER_FLAG_0 (1<<4)
 #define	PAYLOAD_TYPE_USER_FLAG_1 (1<<5)
 #define	PAYLOAD_TYPE_USER_FLAG_2 (1<<6)
-	/* ask for more if you need*/
+#define	PAYLOAD_TYPE_USER_FLAG_3 (1<<7)
+#define	PAYLOAD_TYPE_USER_FLAG_4 (1<<8)
+/* ask for more if you need*/
 
 #define PAYLOAD_AUDIO_CONTINUOUS 0
 #define PAYLOAD_AUDIO_PACKETIZED 1
@@ -50,6 +53,17 @@ extern "C"{
 #define PAYLOAD_TEXT 4
 #define PAYLOAD_OTHER 3  /* ?? */
 
+#define PAYLOAD_TYPE_AVPF_NONE 0
+#define PAYLOAD_TYPE_AVPF_FIR (1 << 0)
+#define PAYLOAD_TYPE_AVPF_PLI (1 << 1)
+#define PAYLOAD_TYPE_AVPF_SLI (1 << 2)
+#define PAYLOAD_TYPE_AVPF_RPSI (1 << 3)
+
+struct _PayloadTypeAvpfParams {
+	unsigned char features; /**< A bitmask of PAYLOAD_TYPE_AVPF_* macros. */
+	uint16_t trr_interval; /**< The interval in milliseconds between regular RTCP packets. */
+};
+
 struct _PayloadType
 {
 	int type; /**< one of PAYLOAD_* macros*/
@@ -63,6 +77,7 @@ struct _PayloadType
 	int channels; /**< number of channels of audio */
 	char *recv_fmtp; /* various format parameters for the incoming stream */
 	char *send_fmtp; /* various format parameters for the outgoing stream */
+	struct _PayloadTypeAvpfParams avpf; /* AVPF parameters */
 	int flags;
 	void *user_data;
 };
@@ -70,6 +85,7 @@ struct _PayloadType
 #ifndef PayloadType_defined
 #define PayloadType_defined
 typedef struct _PayloadType PayloadType;
+typedef struct _PayloadTypeAvpfParams PayloadTypeAvpfParams;
 #endif
 
 #define payload_type_set_flag(pt,flag) (pt)->flags|=((int)flag)
@@ -78,13 +94,15 @@ typedef struct _PayloadType PayloadType;
 
 
 ORTP_PUBLIC PayloadType *payload_type_new(void);
-ORTP_PUBLIC PayloadType *payload_type_clone(PayloadType *payload);
+ORTP_PUBLIC PayloadType *payload_type_clone(const PayloadType *payload);
 ORTP_PUBLIC char *payload_type_get_rtpmap(PayloadType *pt);
 ORTP_PUBLIC void payload_type_destroy(PayloadType *pt);
 ORTP_PUBLIC void payload_type_set_recv_fmtp(PayloadType *pt, const char *fmtp);
 ORTP_PUBLIC void payload_type_set_send_fmtp(PayloadType *pt, const char *fmtp);
 ORTP_PUBLIC void payload_type_append_recv_fmtp(PayloadType *pt, const char *fmtp);
 ORTP_PUBLIC void payload_type_append_send_fmtp(PayloadType *pt, const char *fmtp);
+#define payload_type_get_avpf_params(pt)	((pt)->avpf)
+ORTP_PUBLIC void payload_type_set_avpf_params(PayloadType *pt, PayloadTypeAvpfParams params);
 
 #define payload_type_get_bitrate(pt)	((pt)->normal_bitrate)
 #define payload_type_get_rate(pt)		((pt)->clock_rate)
@@ -107,6 +125,7 @@ ORTP_VAR_PUBLIC PayloadType payload_type_lpc1016;
 ORTP_VAR_PUBLIC PayloadType payload_type_g729;
 ORTP_VAR_PUBLIC PayloadType payload_type_g7231;
 ORTP_VAR_PUBLIC PayloadType payload_type_g7221;
+ORTP_VAR_PUBLIC PayloadType payload_type_cn;
 ORTP_VAR_PUBLIC PayloadType payload_type_g726_40;
 ORTP_VAR_PUBLIC PayloadType payload_type_g726_32;
 ORTP_VAR_PUBLIC PayloadType payload_type_g726_24;
@@ -131,10 +150,14 @@ ORTP_VAR_PUBLIC PayloadType payload_type_silk_nb;
 ORTP_VAR_PUBLIC PayloadType payload_type_silk_mb;
 ORTP_VAR_PUBLIC PayloadType payload_type_silk_wb;
 ORTP_VAR_PUBLIC PayloadType payload_type_silk_swb;
+ORTP_VAR_PUBLIC PayloadType payload_type_aaceld_16k;
 ORTP_VAR_PUBLIC PayloadType payload_type_aaceld_22k;
+ORTP_VAR_PUBLIC PayloadType payload_type_aaceld_32k;
 ORTP_VAR_PUBLIC PayloadType payload_type_aaceld_44k;
+ORTP_VAR_PUBLIC PayloadType payload_type_aaceld_48k;
 ORTP_VAR_PUBLIC PayloadType payload_type_opus;
 ORTP_VAR_PUBLIC PayloadType payload_type_isac;
+ORTP_VAR_PUBLIC PayloadType payload_type_gsm_efr;
 
 /* video */
 ORTP_VAR_PUBLIC PayloadType payload_type_mpv;
