@@ -18,9 +18,7 @@
 */
 
 
-#ifdef _MSC_VER
-#include "ortp-config-win32.h"
-#elif HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 #include "ortp-config.h"
 #endif
 #include "ortp/ortp.h"
@@ -33,15 +31,6 @@ rtp_stats_t ortp_global_stats;
 int ortp_allocations=0;
 #endif
 
-
-#ifdef HAVE_SRTP
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#include "ortp/ortp_srtp.h"
-#endif
-
 RtpScheduler *__ortp_scheduler;
 
 
@@ -49,9 +38,12 @@ RtpScheduler *__ortp_scheduler;
 extern void av_profile_init(RtpProfile *profile);
 
 static void init_random_number_generator(){
+#ifndef WIN32
 	struct timeval t;
 	ortp_gettimeofday(&t,NULL);
 	srandom(t.tv_usec+t.tv_sec);
+#endif
+	/*on windows we're using rand_s, which doesn't require initialization*/
 }
 
 
@@ -60,7 +52,7 @@ static bool_t win32_init_sockets(void){
 	WORD wVersionRequested;
 	WSADATA wsaData;
 	int i;
-	
+
 	wVersionRequested = MAKEWORD(2,0);
 	if( (i = WSAStartup(wVersionRequested,  &wsaData))!=0)
 	{
@@ -89,9 +81,6 @@ void ortp_init()
 	ortp_global_stats_reset();
 	init_random_number_generator();
 
-#ifdef HAVE_SRTP
-	ortp_srtp_init();
-#endif
 	ortp_message("oRTP-" ORTP_VERSION " initialized.");
 }
 
@@ -99,7 +88,7 @@ void ortp_init()
 /**
  *	Initialize the oRTP scheduler. You only have to do that if you intend to use the
  *	scheduled mode of the #RtpSession in your application.
- *	
+ *
 **/
 void ortp_scheduler_init()
 {
@@ -108,7 +97,7 @@ void ortp_scheduler_init()
 	initialized=TRUE;
 #ifdef __hpux
 	/* on hpux, we must block sigalrm on the main process, because signal delivery
-	is ?random?, well, sometimes the SIGALRM goes to both the main thread and the 
+	is ?random?, well, sometimes the SIGALRM goes to both the main thread and the
 	scheduler thread */
 	sigset_t set;
 	sigemptyset(&set);
@@ -118,16 +107,19 @@ void ortp_scheduler_init()
 
 	__ortp_scheduler=rtp_scheduler_new();
 	rtp_scheduler_start(__ortp_scheduler);
-	//sleep(1);
 }
 
 
 /**
  * Gracefully uninitialize the library, including shutdowning the scheduler if it was started.
- *	
+ *
 **/
 void ortp_exit()
 {
+	if (ortp_initialized==0) {
+		ortp_warning("ortp_exit() called without prior call to ortp_init(), ignored.");
+		return;
+	}
 	ortp_initialized--;
 	if (ortp_initialized==0){
 		if (__ortp_scheduler!=NULL)
@@ -135,9 +127,6 @@ void ortp_exit()
 			rtp_scheduler_destroy(__ortp_scheduler);
 			__ortp_scheduler=NULL;
 		}
-#ifdef HAVE_SRTP
-		ortp_srtp_shutdown();
-#endif
 	}
 }
 
@@ -155,7 +144,7 @@ RtpScheduler * ortp_get_scheduler()
 void ortp_global_stats_display()
 {
 	rtp_stats_display(&ortp_global_stats,"Global statistics");
-#ifdef ENABLE_MEMCHECK	
+#ifdef ENABLE_MEMCHECK
 	printf("Unfreed allocations: %i\n",ortp_allocations);
 #endif
 }
@@ -163,19 +152,21 @@ void ortp_global_stats_display()
 /**
  * Print RTP statistics.
 **/
-void rtp_stats_display(const rtp_stats_t *stats, const char *header) { 
+void rtp_stats_display(const rtp_stats_t *stats, const char *header) {
 	ortp_log(ORTP_MESSAGE, "===========================================================");
-	ortp_log(ORTP_MESSAGE, "%s", header);                
+	ortp_log(ORTP_MESSAGE, "%s", header);
 	ortp_log(ORTP_MESSAGE, "-----------------------------------------------------------");
-	ortp_log(ORTP_MESSAGE, "sent                          %20"PRId64" packets", stats->packet_sent);
-	ortp_log(ORTP_MESSAGE, "                              %20"PRId64" bytes  ", stats->sent);
-	ortp_log(ORTP_MESSAGE, "received                      %20"PRId64" packets", stats->packet_recv);
-	ortp_log(ORTP_MESSAGE, "                              %20"PRId64" bytes  ", stats->hw_recv);
-	ortp_log(ORTP_MESSAGE, "incoming delivered to the app %20"PRId64" bytes  ", stats->recv);
-	ortp_log(ORTP_MESSAGE, "lost                          %20"PRId64" packets", stats->cum_packet_loss);
-	ortp_log(ORTP_MESSAGE, "received too late             %20"PRId64" packets", stats->outoftime);        
-	ortp_log(ORTP_MESSAGE, "bad formatted                 %20"PRId64" packets", stats->bad);
-	ortp_log(ORTP_MESSAGE, "discarded (queue overflow)    %20"PRId64" packets", stats->discarded);       
+	ortp_log(ORTP_MESSAGE, "sent                                 %10"PRId64" packets", stats->packet_sent);
+	ortp_log(ORTP_MESSAGE, "                                     %10"PRId64" duplicated packets", stats->packet_dup_sent);
+	ortp_log(ORTP_MESSAGE, "                                     %10"PRId64" bytes  ", stats->sent);
+	ortp_log(ORTP_MESSAGE, "received                             %10"PRId64" packets", stats->packet_recv);
+	ortp_log(ORTP_MESSAGE, "                                     %10"PRId64" duplicated packets", stats->packet_dup_recv);
+	ortp_log(ORTP_MESSAGE, "                                     %10"PRId64" bytes  ", stats->hw_recv);
+	ortp_log(ORTP_MESSAGE, "incoming delivered to the app        %10"PRId64" bytes  ", stats->recv);
+	ortp_log(ORTP_MESSAGE, "incoming cumulative lost             %10"PRId64" packets", stats->cum_packet_loss);
+	ortp_log(ORTP_MESSAGE, "incoming received too late           %10"PRId64" packets", stats->outoftime);
+	ortp_log(ORTP_MESSAGE, "incoming bad formatted               %10"PRId64" packets", stats->bad);
+	ortp_log(ORTP_MESSAGE, "incoming discarded (queue overflow)  %10"PRId64" packets", stats->discarded);
 	ortp_log(ORTP_MESSAGE, "===========================================================");
 }
 
@@ -199,6 +190,6 @@ void rtp_stats_reset(rtp_stats_t *stats){
  * Returns: true if ortp has a version number greater or equal than the required one.
 **/
 bool_t ortp_min_version_required(int major, int minor, int micro){
-	return ((major*1000000) + (minor*1000) + micro) <= 
+	return ((major*1000000) + (minor*1000) + micro) <=
 		   ((ORTP_MAJOR_VERSION*1000000) + (ORTP_MINOR_VERSION*1000) + ORTP_MICRO_VERSION);
 }
