@@ -17,6 +17,10 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#ifdef HAVE_CONFIG_H
+#include "ortp-config.h"
+#endif
+
 #include "ortp/str_utils.h"
 
 
@@ -36,6 +40,7 @@ void mblk_init(mblk_t *mp)
 #if defined(ORTP_TIMESTAMP)
 	memset(&(mp->timestamp), 0, sizeof(struct timeval));
 #endif
+	mp->ttl_or_hl = 0;
 }
 
 void mblk_meta_copy(const mblk_t *source, mblk_t *dest) {
@@ -44,6 +49,7 @@ void mblk_meta_copy(const mblk_t *source, mblk_t *dest) {
 #if defined(ORTP_TIMESTAMP)
 	dest->timestamp = source->timestamp;
 #endif
+	dest->ttl_or_hl = source->ttl_or_hl;
 }
 
 dblk_t *datab_alloc(size_t size){
@@ -57,11 +63,11 @@ dblk_t *datab_alloc(size_t size){
 	return db;
 }
 
-static inline void datab_ref(dblk_t *d){
+static ORTP_INLINE void datab_ref(dblk_t *d){
 	d->db_ref++;
 }
 
-static inline void datab_unref(dblk_t *d){
+static ORTP_INLINE void datab_unref(dblk_t *d){
 	d->db_ref--;
 	if (d->db_ref==0){
 		if (d->db_freefn!=NULL)
@@ -264,7 +270,7 @@ void msgpullup(mblk_t *mp,size_t len)
 }
 
 
-mblk_t *copyb(mblk_t *mp)
+mblk_t *copyb(const mblk_t *mp)
 {
 	mblk_t *newm;
 	int len=(int) (mp->b_wptr-mp->b_rptr);
@@ -275,7 +281,7 @@ mblk_t *copyb(mblk_t *mp)
 	return newm;
 }
 
-mblk_t *copymsg(mblk_t *mp)
+mblk_t *copymsg(const mblk_t *mp)
 {
 	mblk_t *newm=0,*m;
 	m=newm=copyb(mp);
