@@ -28,6 +28,7 @@
 #define UTILS_H
 
 #include "ortp/event.h"
+#include "ortp/rtpsession.h"
 
 struct _OList {
 	struct _OList *next;
@@ -35,26 +36,15 @@ struct _OList {
 	void *data;
 };
 
-typedef struct _OList OList;
-
 
 #define o_list_next(elem) ((elem)->next)
+#define o_list_prev(elem) ((elem)->prev)
 
 OList * o_list_append(OList *elem, void * data);
 OList * o_list_remove(OList *list, void *data);
 OList * o_list_free(OList *elem);
 OList *o_list_remove_link(OList *list, OList *elem);
 
-#ifndef MIN
-#define MIN(a,b) (((a)>(b)) ? (b) : (a))
-#endif
-#ifndef MAX
-#define MAX(a,b) (((a)>(b)) ? (a) : (b))
-#endif
-
-#define return_if_fail(expr) if (!(expr)) {printf("%s:%i- assertion"#expr "failed\n",__FILE__,__LINE__); return;}
-#define return_val_if_fail(expr,ret) if (!(expr)) {printf("%s:%i- assertion" #expr "failed\n",__FILE__,__LINE__); return (ret);}
-
 
 #define INT_TO_POINTER(truc)	((long)(long)(truc))
 #define POINTER_TO_INT(truc)	((int)(long)(truc))
@@ -89,4 +79,10 @@ typedef union{
 
 void ortp_ev_queue_put(OrtpEvQueue *q, OrtpEvent *ev);
 
+uint64_t ortp_timeval_to_ntp(const struct timeval *tv);
+
+bool_t ortp_stream_is_ipv6(OrtpStream *os);
+
+int _rtp_session_sendto(RtpSession *session, bool_t is_rtp, mblk_t *m,  int flags, const struct sockaddr *destaddr, socklen_t destlen);
+int _ortp_sendto(ortp_socket_t sockfd, mblk_t *m, int flags, const struct sockaddr *destaddr, socklen_t destlen);
 #endif
